@@ -197,6 +197,7 @@ public:
 		static const char *chkInvoke(script *img, script::header *scr, script::line_t *line);
 		static const char *chkWhen(script *img, script::header *scr, script::line_t *line);
 		static const char *chkStrict(script *img, script::header *scr, script::line_t *line);
+		static const char *chkExpr(script *img, script::header *scr, script::line_t *line);
 	};
 
 	/**
@@ -272,6 +273,21 @@ public:
 		 */
 		unsigned getResource(void);
 
+		/**
+		 * Get count of members in a list.
+		 * @param list to count.
+		 * @return number of members in list.
+		 */
+		unsigned listCount(const char *list);
+
+		/**
+		 * Get count of members in a list.
+		 * @param list of members to search.
+		 * @param index of member to list.
+		 * @return list member or NULL if not found.
+		 */
+		const char *listOffset(const char *list, unsigned index);
+
 	protected:
 		script::symbol *find(const char *id);
 		void skip(void);
@@ -321,6 +337,7 @@ public:
 		script::symbol *createSymbol(const char *id);
 		script::symbol *getVar(const char *id, const char *value = NULL);
 		const char *getValue(void);
+		const char *getContent(void);
 		const char *getContent(const char *text);
 		const char *getKeyword(const char *id);
 		script::method_t getLooping(void);
@@ -369,6 +386,8 @@ public:
 	class __EXPORT methods : public script::interp
 	{
 	public:	
+		bool scrApply(void);
+		bool scrExpr(void);
 		bool scrVar(void);
 		bool scrSet(void);
 		bool scrAdd(void);
