@@ -23,6 +23,23 @@
 
 using namespace UCOMMON_NAMESPACE;
 
+static const char *getArgument(script::line_t *line, unsigned *index)
+{
+	const char *cp;
+
+	for(;;) {
+		if(*index >= line->argc)
+			return NULL;
+		cp = line->argv[*index];
+		++*index;
+		if(*cp == '=') {
+			++*index;
+			continue;
+		}
+		return cp;
+	}
+}
+
 static const char *getKeyword(const char *kw, script::line_t *line)
 {
 	unsigned index = 0;
@@ -611,12 +628,31 @@ const char *script::checks::chkPack(script *img, script::header *scr, script::li
 
 const char *script::checks::chkSet(script *img, script::header *scr, script::line_t *line)
 {
+	unsigned drop = 0;
 	unsigned index = 1;
 	const char *cp;
 
 	if(!line->argc)
 		return "no symbols to assign";
 
+	if(line->argc > 2) {
+		if(String::equal(line->argv[1], ":="))
+			drop = 1;
+		else if(String::equal(line->argv[1], "+=")) {
+			drop = 1;
+			line->method = (method_t)&methods::scrAdd;
+		}
+	}
+
+	if(drop) {
+		--line->argc;
+		while(drop && drop < line->argc) {
+			line->argv[drop] = line->argv[drop + 1];
+			++drop;
+		}
+		line->argv[drop] = NULL;
+	}
+
 	if(line->argc < 2)
 		return "no values to assign";
 
@@ -798,6 +834,65 @@ const char *script::checks::chkConditional(script *img, script::header *scr, scr
 	return "conditional expression missing";
 }
 	
+const char *script::checks::chkExpr(script *img, script::header *scr, script::line_t *line)
+{
+	unsigned index = 0;
+	const char *cp;
+
+	if(line->argc < 3)
+		return "no variable to assign";
+
+	while(index < line->argc) {
+		cp = line->argv[index++];
+		if(*cp == '=') {
+			if(!String::equal(cp, "=decimals"))
+				return "invalid keyword for expression";
+			++index;
+		}
+	}
+
+	index = 0;
+	cp = getArgument(line, &index);
+	if(!cp)
+		return "no assignment";
+
+	if(*cp == '&')
+			return "cannot assign literal as symbol";
+
+	if(*cp == '$')
+		return "cannot assign format as symbol";
+
+	if(*cp == '@' || *cp == '^')
+		return "cannot assign label as symbol";
+
+	if(*cp == '?')
+		return "cannot assign expression as symbol";
+
+	script::strict::createVar(img, scr, cp);
+	
+	cp = getArgument(line, &index);
+	if(!cp)
+		return "expression incomplete";
+
+	if(!String::equal(cp, ":=") && !String::equal(cp, "?=") && !String::equal(cp, "+=") && !String::equal(cp, "-=") && !String::equal(cp, "*=") && !String::equal(cp, "/="))
+		return "expression must start with assignment expression";
+
+	while(index < line->argc) {
+		cp = getArgument(line, &index);
+		if(!isValue(cp))
+			return "malformed expression";
+
+		cp = getArgument(line, &index);
+		if(!cp)
+			break;
+		if(!String::equal(cp, "*") && !String::equal(cp, "/") && !String::equal(cp, "+") && !String::equal(cp, "-"))
+			return "invalid expression used";
+		if(index == line->argc)
+			return "incomplete expression";
+	}
+	return NULL;
+}
+
 const char *script::checks::chkVar(script *img, script::header *scr, script::line_t *line)
 {
 	unsigned index = 0;
