@@ -191,7 +191,14 @@ static bool preparse(char **tokens)
 		return false;
 	case '/':
 	case '*':
+		if(isspace(str[1]))
+			break;
+		if(str[1] == '=' && isspace(str[2]))
+			break;
+		return false;
 	case ':':
+		if(str[1] == '=' && isspace(str[2]))
+			return true;
 	case ',':
 	case '`':
 	case '(':
@@ -206,6 +213,10 @@ static bool preparse(char **tokens)
 			++*tokens;
 			return true;
 		}
+		if(isspace(str[1]))
+			break;
+		if(str[1] == '=' && isspace(str[2]))
+			break;
 		return false;	
 	case '.':
 		if(isdigit(str[1]))
@@ -214,6 +225,10 @@ static bool preparse(char **tokens)
 	case '-':
 		if(isalnum(str[1]) || str[1] == '.')
 			return true;
+		if(isspace(str[1]))
+			break;
+		if(str[1] == '=' && isspace(str[2]))
+			break;
 		return false;
 	case '\'':
 	case '\"':
@@ -330,6 +345,7 @@ void script::init(void)
 		{"elif", (method_t)&methods::scrElif, (check_t)&checks::chkElif},
 		{"else", (method_t)&methods::scrElse, (check_t)&checks::chkElse},
 		{"endif", (method_t)&methods::scrEndif, (check_t)&checks::chkEndif},
+		{"expr", (method_t)&methods::scrExpr, (check_t)&checks::chkExpr},
 		{"strict", (method_t)NULL, (check_t)&checks::chkStrict},
 		{"apply", (method_t)NULL, (check_t)&checks::chkApply},
 		{"_ifthen", (method_t)&methods::scrWhen, (check_t)&checks::chkWhen},
