@@ -95,6 +95,51 @@ char *script::interp::getTemp(void)
 	return ptr;
 }
 
+const char *script::interp::listOffset(const char *list, unsigned index)
+{
+	char quote = 0;
+
+	if(!list || !*list)
+		return NULL;
+
+	if(!index)
+		return list;
+
+	while(*list && index) {	
+		if(*list == ',' && !quote) {
+			--index;
+			if(!index) 
+				return ++list;
+		} else if(*list == quote)
+			quote = 0;
+		else if(*list == '\"')
+			quote = *list;
+		++list;
+	}
+	return NULL;
+}
+		
+unsigned script::interp::listCount(const char *data)
+{
+	unsigned count = 0;
+	char quote = 0;
+
+	if(!data || !*data)
+		return 0;
+
+	++count;
+	while(*data) {
+		if(*data == ',' && !quote)
+			++count;
+		else if(*data == quote)
+			quote = 0;
+		else if(*data == '\"')
+			quote = *data;
+		++data;
+	}
+	return count;
+}
+
 const char *script::interp::getFormat(script::symbol *sym, const char *id, char *tp)
 {
 #ifdef	__MINGW32__
@@ -103,11 +148,13 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 	long val;
 #endif
 
-	unsigned count = 0, pos;
+	unsigned dcount = 0, pos;
 	const char *cp;
+	char *ep;
 	char idbuf[32];
 	unsigned len;
-	char quote;
+	char quote = 0;
+	script::symbol *index = NULL;
 
 	if(String::equal(id, "len:", 4)) 
 		snprintf(tp, script::sizing + 1, "%u", (unsigned)strlen(sym->data));
@@ -116,6 +163,38 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 		snprintf(sym->data, sym->size + 1, NUM_FORMAT, ++val);
 		return sym->data;
 	}
+	else if(String::equal(id, "count:", 6))
+		snprintf(tp, script::sizing + 1, "%u", listCount(sym->data)); 
+	else if(String::equal(id, "offset/", 7)) {
+		id += 7;
+		pos = atoi(id);
+		if(pos)
+			--pos;
+		else {
+			snprintf(tp, script::sizing + 1, "%s", id);
+			ep = strchr(tp, ':');
+			*ep = 0;
+			index = find(tp);
+			if(!index)
+				return "";
+			pos = atoi(index->data);
+			if(pos)
+				--pos;
+		}
+		cp = listOffset(sym->data, pos);
+		if(!cp || !*cp)
+			return "";
+		if(*cp == '\"')
+			quote = *(cp++);
+		while(dcount < script::sizing && *cp) {
+			if(*cp == quote)
+				break;
+			if(!quote && *cp == ',')
+				break;
+			tp[dcount++] = *(cp++);
+		}
+		tp[dcount] = 0;
+	}
 	else if(String::equal(id, "dec:", 4) && sym->size) {
 		val = atoi(sym->data);
 		snprintf(sym->data, sym->size + 1, NUM_FORMAT, --val);
@@ -138,7 +217,7 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 			++cp;
 		else
 			cp = "";
-		while(count++ < script::decimals && pos < script::sizing) {
+		while(dcount++ < script::decimals && pos < script::sizing) {
 			if(*cp && isdigit(*cp))
 				tp[pos++] = *(cp++);
 			else
@@ -148,10 +227,10 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 	}
 	else if(String::equal(id, "find/", 5)) {
 		id += 5;
-		count = atoi(id);
-		if(count) {
+		dcount = atoi(id);
+		if(dcount) {
 			cp = sym->data;
-			while(count > 1 && *cp) {
+			while(dcount > 1 && *cp) {
 				if(*cp == '\"') {
 					quote = *cp;
 					++cp;
@@ -171,17 +250,17 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 					++cp;
 					continue;
 				}
-				--count;
+				--dcount;
 				++cp;
 			}
 		}
 		else {
-			count = 1;
+			dcount = 1;
 			idbuf[0] = ',';
-			while(count < 30 && *id && *id != ':')
-				idbuf[count++] = *(id++);
-			idbuf[count++] = '=';
-			idbuf[count] = 0;
+			while(dcount < 30 && *id && *id != ':')
+				idbuf[dcount++] = *(id++);
+			idbuf[dcount++] = '=';
+			idbuf[dcount] = 0;
 			cp = sym->data;
 			len = strlen(idbuf);
 			if(!strncmp(cp, idbuf + 1, len - 1))
@@ -191,22 +270,22 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 			else
 				cp = "";
 		}
-		count = 0;
+		dcount = 0;
 		if(*cp == '\"') {
 			quote = *cp;
 			++cp;
 		}
 		else
 			quote=',';
-		while(count < script::sizing && *cp && *cp != quote) {
+		while(dcount < script::sizing && *cp && *cp != quote) {
 			if(*cp == '=' && quote == ',' && cp[1] == '\"') {
-				tp[count++] = *(cp++);
+				tp[dcount++] = *(cp++);
 				quote = *(cp++);
 			}
 			else
-				tp[count++] = *(cp++);
+				tp[dcount++] = *(cp++);
 		}
-		tp[count] = 0;
+		tp[dcount] = 0;
 	}
 	else if(String::equal(id, "bool:", 5)) {
 		if(atoi(sym->data) > 0 || tolower(sym->data[0]) == 't' || tolower(sym->data[0] == 'y'))
@@ -246,7 +325,8 @@ const char *script::interp::getContent(const char *cp)
 	case '&':
 	case '=':
 	case '+':
-		return ++cp;
+		if(cp[1] && cp[1] != '=')
+			return ++cp;
 	}
 	return cp;
 }
@@ -276,6 +356,23 @@ script::method_t script::interp::getLooping(void)
 	return stack[frame - 1].line->method;
 }
 
+const char *script::interp::getContent(void)
+{
+	const char *cp;
+	line_t *line = stack[frame].line;
+	while(stack[frame].index < line->argc) {
+		cp = line->argv[stack[frame].index++];
+		switch(*cp) {
+		case '=':
+			++stack[frame].index;
+			break;
+		default:
+			return cp;
+		}
+	}
+	return NULL;
+}
+
 const char *script::interp::getValue(void)
 {
 	const char *cp;
@@ -817,11 +914,11 @@ bool script::interp::tryexit(void)
 
 bool script::interp::step(void)
 {
-	unsigned count = script::stepping;
+	unsigned scount = script::stepping;
 	line_t *line = stack[frame].line;
 	bool rtn = true;
 
-	while(line && rtn && count--) {
+	while(line && rtn && scount--) {
 		rtn = (this->*(line->method))();
 		line = stack[frame].line;
 	}
