@@ -39,37 +39,31 @@ bool script::methods::scrForeach(void)
 		sym = getVar(line->argv[0]);
 
 	if(!sym)
-		return "symbol not found";
+		return error("symbol not found");
 
 	if(!sym->size)
-		return "symbol not writable";
+		return error("symbol not writable");
 
-	cp = getContent(line->argv[1]);
-	if(index >= strlen(cp)) {
+	cp = listOffset(getContent(line->argv[1]), index);
+	if(cp == NULL) {
 		stack[frame].index = 0;
 		skip();
 		return scrBreak();
 	}
 
-	while(pos < sym->size && cp[index]) {
-		if(!quote && cp[index] == ',')
+	if(*cp == '\"')
+		quote = *(cp++);
+
+	while(pos < sym->size && *cp) {
+		if(*cp == ',' && !quote)
 			break;
-		if(quote && cp[index] == quote && cp[index + 1] == ',')
+		if(*cp == quote)
 			break;
-		if(cp[index] == '\"')
-			quote = cp[index++];
-		else
-			sym->data[pos++] = cp[index++];
+		sym->data[pos++] = *(cp++);
 	}
 
-	while(cp[index] && cp[index] != ',')
-		++index;
-
-	if(cp[index] == ',')
-		++index;
-
 	sym->data[pos] = 0;
-	stack[frame].index = index;	
+	stack[frame].index = ++index;	
 	push();
 	skip();
 	return true;
@@ -403,6 +397,74 @@ bool script::methods::scrReturn(void)
 	return false;
 }
 
+bool script::methods::scrExpr(void)
+{
+	unsigned index = 0;
+	unsigned decimals = script::decimals;
+	const char *id, *cp, *op, *aop;
+	float result, value;
+	char cvt[8];
+	char buf[32];
+
+	cp = getKeyword("decimals");
+	if(cp)
+		decimals = atoi(cp);
+
+	id = getContent();
+
+	aop = getValue();
+	result = atof(getValue());
+
+	while(NULL != (op = getValue())) {
+		switch(*op) {
+		case '+':
+			result += atof(getValue());
+			break;
+		case '-':
+			result -= atof(getValue());
+			break;
+		case '*':
+			result *= atof(getValue());
+			break;
+		case '/':
+			value = atof(getValue());
+			if(value == 0.) {
+				return error("div by zero");
+			}
+			result /= value;
+		}
+	}
+	cp = getContent(id);
+	if(cp)
+		value = atof(cp);
+	else
+		value = 0;
+	if(String::equal(aop, "+="))
+		value += result;
+	else if(String::equal(aop, "-="))
+		value -= result;
+	else if(String::equal(aop, "*="))
+		value *= result;
+	else if(String::equal(aop, "/=") && result)
+		value /= result;
+	else if(String::equal(aop, "?=") || String::equal(aop, ":="))
+		value = result;
+
+	stack[frame].index = 0;
+	cvt[0] = '%';
+	cvt[1] = '.';
+	cvt[2] = '0' + decimals;
+	cvt[3] = 'f';
+	cvt[4] = 0;
+	snprintf(buf, sizeof(buf), cvt, value);
+
+	if(!getVar(id, buf))
+		return error("invalid symbol");
+
+	skip();
+	return true;
+}
+		
 bool script::methods::scrVar(void)
 {
 	unsigned index = 0;
